enyo.depends(
  "date_format/date_format.js",
  "gts-plugins/DatePicker",
  "font-onyx/lib/Icon.js",
  "font-onyx/lib/IconButton.js",
  "font-onyx/lib/TextIcon.js"
);
